Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/ssd1327_simpletest.py
    :caption: examples/ssd1327_simpletest.py
    :linenos:

Gamma test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/ssd1327_gamma.py
    :caption: examples/ssd1327_gamma.py
    :linenos:
